@@ -1,9 +1,6 @@
 # create json for multigraph
-multigraphJSON <- function(multi,dir){
+multigraphJSON <- function(multi,multinames,dir){
 json <- character(length(multi))
-multinames <- names(multi)
-if(is.null(multinames))
-  multinames <- paste0("graph",seq_along(multi))
 for(i in seq_along(multi)){
   graph <- multi[[i]]
   gClass <- class(graph)
@@ -18,7 +15,7 @@ for(i in seq_along(multi)){
   if(gClass == "barCoin")
     jsongraph <- barplotJSON(graph)
   if(gClass == "character" && file.exists(paste0(graph,'/index.html'))){
-    gClass = 'iFrame'
+    gClass <- 'iFrame'
     graphName <- sub("^.*/","",graph)
     dir.create(paste0(dir,'/data'), showWarnings = FALSE)
     file.copy(graph, paste0(dir,'/data'), recursive = TRUE)
@@ -30,14 +27,30 @@ json <- paste0("{",paste0(json,collapse=","),"}")
 return(json)
 }
 
+multiGraph <- function(multi,multinames,language,dir){
+ if(language[1]=="es")
+    language <- "es.js"
+  else
+    language <- "en.js"
+  createHTML(dir, c("reset.css","styles.css"), c("d3.min.js","jspdf.min.js","jszip.min.js","functions.js",language,"colorScales.js","multigraph.js","network.js","barplot.js","timeline.js"), function(){ return(multigraphJSON(multi,multinames,dir)) }, FALSE)
+}
+
+polyGraph <- function(multi,multinames,language,dir){
+  createHTML(dir, NULL, c("d3.min.js","polygraph.js"), toJSON(multinames), FALSE)
+  multiGraph(multi,multinames,language,paste0(dir,"/multiGraph"))
+}
+
 #create html wrapper for multigraph
-multigraphCreate <- function(..., language = c("en","es"), dir = "MultiGraph", show = TRUE){
+multigraphCreate <- function(...,  parallel = FALSE, language = c("en","es"), dir = "MultiGraph", show = TRUE){
 multi <- list(...)
-if(language[1]=="es")
-  language <- "es.js"
-else
-  language <- "en.js"
-createHTML(dir, c("reset.css","styles.css"), c("d3.min.js","jspdf.min.js","jszip.min.js","functions.js",language,"colorScales.js","multigraph.js","network.js","barplot.js","timeline.js"), function(){ return(multigraphJSON(multi,dir)) })
+multinames <- names(multi)
+if(is.null(multinames))
+  multinames <- paste0("graph",seq_along(multi))
+if(parallel){
+  polyGraph(multi,multinames,language,dir)
+}else{
+  multiGraph(multi,multinames,language,dir)
+}
 if(identical(show,TRUE))
   browseURL(normalizePath(paste(dir, "index.html", sep = "/")))
 }
