@@ -27,6 +27,8 @@ var texts = {
     showhidelabels: "Mostrar/ocultar etiquetas",
     showhidelegend: "Mostrar/ocultar leyenda",
     showhideaxes: "Mostrar/ocultar ejes",
+    showhideimages: "Mostrar/ocultar imágenes",
+    showhidesidebar: "Mostrar/ocultar control lateral",
     stopresume: "Parar/reanudar",
 	netheatmap: "Red/mapa de color",
     isolateselection: "Filtrar selección",
@@ -57,6 +59,7 @@ var texts = {
     Size: "Tamaño",
     Color: "Color",
     Shape: "Forma",
+    Slegend: "Sleyenda",
     Width: "Anchura",
     Weight: "Ponderación",
 	Intensity: "Intensidad",
